# em_om reader

## Purpose
Parse data from orientation imaging microscopy and microstructures.

## TODO
* Add description specific for OIM
* Remove the focus of the README.md on the NOMAD OASIS product

## Contact person for this reader
Markus Kühbach